FileUploadOptions class

File upload options

Constructors

FileUploadOptions({required String url, required String filePath, String fieldName = 'file', Map<String, String>? headers, Map<String, String>? fields, void onProgress(int sent, int total)?})
const

Properties

fieldName String
final
fields Map<String, String>?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
onProgress → void Function(int sent, int total)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited