PollingConnectivityAdapter class

Default ConnectivityAdapter that uses periodic HTTP HEAD pings to determine connectivity.

This is a foreground-only approach suitable for apps that do not include connectivity_plus. For production use, provide a platform-specific adapter.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStatus() Future<ConnectivityInfo>
Get the current connectivity status.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startMonitoring(ConnectivityChangeHandler onChange) → void
Start monitoring for connectivity changes.
override
stopMonitoring() → void
Stop monitoring for connectivity changes and release resources.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited