RandomizationConfig class

Randomization configuration for question options

Constructors

RandomizationConfig({String type = 'none', List<String>? excludeOptionIds, Map<String, dynamic>? anchorPositions})
const
RandomizationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

anchorPositions Map<String, dynamic>?
final
excludeOptionIds List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited