ThemeAnimations class

Constructors

ThemeAnimations({bool? enabled, int? transitionDuration, String? questionEntrance})
const
ThemeAnimations.fromJson(Map<String, dynamic> json)
factory

Properties

enabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
questionEntrance String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited