getLineHeight function

double getLineHeight(
  1. double fontSize,
  2. ResolvedTheme theme
)

Computes the line height (in logical pixels) for a given fontSize.

Flutter's TextStyle.height is a multiplier, but this function returns the absolute pixel value which is useful for padding/spacing calculations.

Implementation

double getLineHeight(double fontSize, ResolvedTheme theme) {
  return (fontSize * theme.fonts.lineHeight).roundToDouble();
}