BiometricAdapter class abstract
Abstract adapter for platform-specific biometric authentication.
Implementations should use the appropriate platform APIs (e.g.,
local_auth for Flutter) to authenticate the user via biometrics.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
String reason) → Future< BiometricAuthResult> - Prompt the user for biometric authentication.
-
getBiometricType(
) → Future< BiometricType> - Get the type of biometric authentication available.
-
isAvailable(
) → Future< bool> - Check if biometric authentication is available on this device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited