OfflinePackageConfig class
Offline package configuration
Constructors
Properties
- compressionLevel → int
-
final
- customBranding → bool
-
final
- encryptionEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeMedia → bool
-
final
- maxResponses → int?
-
final
- offlineValidation → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited