OfflineResponseMetadata class
Metadata for offline responses
Constructors
-
OfflineResponseMetadata({String? sessionId, String? completedAt, int? totalTimeMs, Map<
String, int> ? questionTimes, OfflineDeviceInfo? deviceInfo, OfflineLocation? location, String? offlineStartedAt, int? packageVersion}) -
const
-
OfflineResponseMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- completedAt → String?
-
final
- deviceInfo → OfflineDeviceInfo?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → OfflineLocation?
-
final
- offlineStartedAt → String?
-
final
- packageVersion → int?
-
final
-
questionTimes
→ Map<
String, int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- totalTimeMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited